@@ -312,7 +312,7 @@ def sort_dict_list_by_list(dict_list: List[dict], sort_value_list: List[str], na
     return ordered_list
 
 
-def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", name_key="name"):
+def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", value_key="name"):
     """
     查找树形结构中每个目标元素的所有父级（包括间接父级）
 
@@ -330,7 +330,7 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
         for node in nodes:
             node_map[node[key]] = {
                 parent_key: node.get(parent_key, ''),
-                name_key: node.get(name_key, ''),
+                value_key: node.get(value_key, ''),
                 children_key: node.get(children_key, []),
                 key: node[key]
             }
@@ -350,7 +350,8 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
 
         parent_id = node_info[parent_key]
         if parent_id and parent_id in node_map:
-            parents_list.append(parent_id)
+            parent_info = node_map.get(parent_id, {}) or {}
+            parents_list.append(parent_info.get(value_key, {}))
             return find_parents(parent_id, parents_list)
         return parents_list
 
@@ -364,3 +365,56 @@ def find_all_parents(tree, target_list, parent_key="parent_id", key="id", childr
             result[target] = []  # 如果节点不存在，返回空列表
 
     return result
+
+
+def find_all_children(tree: list, target_list, parent_key="parent_id", key="id", children_key="children",
+                      value_key="name"):
+    """
+    查找树形结构中每个目标元素的所有子级（包括间接子级）
+
+    参数:
+    target_list: 需要查找子级的目标值列表
+
+    返回:
+    字典，key为目标值，value为该目标的所有子级列表（包括所有后代）
+    """
+    # 创建节点映射表：value -> node_info (包含parent_id和children)
+    node_map = {}
+
+    def build_map(nodes):
+        """递归构建节点映射表"""
+        for node in nodes:
+            node_map[node[key]] = {
+                parent_key: node.get(parent_key, ''),
+                value_key: node.get(value_key, ''),
+                children_key: node.get(children_key, []),
+                key: node[key]
+            }
+            if children_key in node and node[children_key]:
+                build_map(node[children_key])
+
+    # 构建节点映射表
+    build_map(tree)
+
+    result = {}
+
+    def find_children(parent_id, children_list):
+        """递归查找某个节点的所有子级"""
+        # 查找所有直接子节点
+        for node_id, node_info in node_map.items():
+            if node_info[parent_key] == parent_id:
+                children_list.append(node_info.get(value_key, ''))
+                # 递归查找孙子节点
+                find_children(node_id, children_list)
+        return children_list
+
+    # 为每个目标值查找所有子级
+    for target in target_list:
+        if target in node_map:
+            # 查找该节点的所有子级（包括所有后代）
+            children = find_children(target, [])
+            result[target] = children
+        else:
+            result[target] = []  # 如果节点不存在，返回空列表
+
+    return result
